<?php

$params = require(__DIR__ . '/params.php');

$config = [
    'id' => 'medkey-web',
    'basePath' => dirname(__DIR__),
    // @todo в дальнейшем bootstrap может быть у каждого модуля свой
    'bootstrap' => [
        'log',
        \app\modules\crm\Bootstrap::class,
        \app\modules\security\Bootstrap::class,
        \app\modules\dashboard\Bootstrap::class,
        \app\modules\workplan\Bootstrap::class,
        \app\modules\medical\Bootstrap::class,
        \app\modules\organization\Bootstrap::class,
        \app\modules\config\Bootstrap::class,
        \app\modules\location\Bootstrap::class,
    ],
    'aliases' => [
        '@bower' => '@vendor/bower-asset',
        '@npm'   => '@vendor/npm-asset',
    ],
    'defaultRoute' => '/dashboard/ui/dashboard/index',
    'homeUrl' => ['/dashboard/ui/dashboard/index'], // use in Breadcrumbs class
    'version' => '0.2',
    'sourceLanguage' => 'en-US',
    'language' => 'ru-RU',
    'components' => [
        'request' => [
            'class' => \app\common\web\Request::class,
            'cookieValidationKey' => '1@3$5^qWeRvBnMj!K#l%Oi',
            'parsers' => [
                'application/json' => \app\common\web\JsonParser::class,
            ],
        ],
        'i18n' => [
            'class' => \app\common\i18n\I18N::class,
            'translations' => [
                'app*' => [
                    'class' => 'app\common\i18n\PhpMessageSource',
                    'basePath' => '@app/messages',
                    'fileMap' => [
                        'app' => 'app.php',
                        'app/error' => 'error.php',
                        'app/attributes/user' => 'attributes/user.php',
                    ],
                ],
                'yii' => [
                    'class' => 'app\common\i18n\PhpMessageSource',
                    'basePath' => '@app/messages',
                ],
            ],
        ],
	    'response' => [
	    	'class' => 'app\common\web\Response',
//		    'exceptionKeys' => YII_DEBUG ? ['code', 'message', 'file', 'line', 'trace' => function (\Exception $e) {
//		    	return array_slice($e->getTrace(), 0, 1);
//		    }] : ['code', 'message'],
	    ],
        'cache' => [
            'class' => 'yii\caching\FileCache',
        ],
        'user' => [
            'class' => \app\common\web\User::class,
            'identityClass' => \app\modules\security\models\orm\User::class,
            'enableAutoLogin' => true,
            'enableSession' => true,
        ],
        'eventDispatcher' => [ // todo deprecated. local usage
            'class' => \Symfony\Component\EventDispatcher\EventDispatcher::class,
        ],
        'urlManager' => [
            'enablePrettyUrl' => true,
            'showScriptName' => false,
            'rules' => [
                [
                    'pattern' => '<module>/<controller>/<action>',
                    'route' => '<module>/<controller>/<action>',
                    'suffix' => ''
                ],
            ]
        ],
        'assetManager' => [
            'class' => \yii\web\AssetManager::class,
            'appendTimestamp' => true,
        ],
        'acl' => [
            'class' => \app\common\acl\Acl::class,
        ],
//        'authManager' => [
//            'class' => \app\modules\security\common\rbac\AccessManager::class,
//        ],
        'configManager' => [
            'class' => \app\common\config\ConfigManager::class,
        ],
        'log' => [
            'traceLevel' => YII_DEBUG ? 3 : 0,
            'targets' => [
                [
                    'class' => 'yii\log\FileTarget',
                    'levels' => ['error', 'warning'],
                ],
            ],
        ],
        'db' => require(__DIR__ . '/db.php'),
        'formatter' => [
            'class' => \app\common\base\Formatter::class,
        ],
//        'view' => [
//            'class' => 'app\common\web\View',
//            'theme' => [
//                'basePath' => '@app/themes/basic',
//                'baseUrl' => '@web/themes/basic',
//            ],
//        ],
        'view' => [
            'class' => \app\common\web\View::class,
	        'theme' => [
                'basePath' => '@app/themes/basic',
                'baseUrl' => '@web/themes/basic',
		        'pathMap' => [
                    '@app/views' => '@app/themes/basic',
                    '@app/modules' => '@app/themes/basic/modules',
		        ],
	        ],
        ],
    ],
    'modules' => [
        'dashboard' => [
            'class' => \app\modules\dashboard\DashboardModule::class,
            'aliasId' => 'Рабочий стол',
        ],
        'security' => [
            'class' => \app\modules\security\SecurityModule::class,
            'aliasId' => 'Безопасность',
        ],
        'config' => [
            'class' => \app\modules\config\ConfigModule::class,
            'aliasId' => 'Конфигурация'
        ],
        'organization' => [
            'class' => \app\modules\organization\OrganizationModule::class,
            'aliasId' => 'Орг. штатная структура'
        ],
        'crm' => [
            'class' => \app\modules\crm\CrmModule::class,
            'aliasId' => 'CRM'
        ],
        'medical' => [
            'class' => \app\modules\medical\MedicalModule::class,
            'aliasId' => 'Медицина'
        ],
        'location' => [
            'class' => \app\modules\location\LocationModule::class,
            'aliasId' => 'Локация'
        ],
        'help' => [
            'class' => \app\modules\help\HelpModule::class,
            'aliasId' => 'Хелп'
        ],
        'workplan' => [
            'class' => \app\modules\workplan\WorkplanModule::class,
            'aliasId' => 'Рабочий план'
        ],
    ],
    'params' => $params,
];
if (YII_DEBUG) {
    $config['bootstrap'][] = 'debug';
    $config['modules']['debug'] = [
        'class' => 'yii\debug\Module',
        'allowedIPs' => ['127.0.0.1', '127.0.0.1:100', '::1', '10.0.2.2'],
    ];
}
if (YII_ENV_DEV) {
    $config['bootstrap'][] = 'gii';
    $config['modules']['gii'] = [
        'class' => 'yii\gii\Module',
    ];
}

return $config;