<?php
namespace app\modules\medical\application;

use app\common\data\ActiveDataProvider;
use app\common\helpers\CommonHelper;
use app\common\service\ApplicationService;
use app\common\service\exception\AccessApplicationServiceException;
use app\modules\medical\models\finders\EhrFilter;
use app\modules\medical\models\orm\Ehr;
use yii\base\Model;

/**
 * Class EhrApplicationService
 * @package app\modules\medical\application
 *
 * 
 */
class EhrService extends ApplicationService implements EhrServiceInterface
{
    /**
     * @inheritdoc
     */
    public function getEhrById($id)
    {
        return Ehr::findOne($id);
    }

    /**
     * @inheritdoc
     */
    public function getEhrList(Model $form)
    {
        /** @var $form EhrFilter */
        if (!$this->isAllowed('getEhrList')) {
            throw new AccessApplicationServiceException('Доступ запрещен.');
        }
        $query = Ehr::find()
            ->andFilterWhere([
                'patient_id' => $form->patientId,
                'cast(updated_at as date)' =>
                    empty($form->updatedAt) ? null : \Yii::$app->formatter->asDate($form->updatedAt, CommonHelper::FORMAT_DATE_DB),
                'type' => $form->type,
            ])
            ->andFilterWhere([
                'like',
                'number',
                $form->number,
            ]);
        return new ActiveDataProvider([
            'query' => $query,
            'pagination' => [
                'pageSize' => 10
            ],
        ]);
    }

    /**
     * @inheritdoc
     */
    public function getPrivileges()
    {
        return [
            'getEhrList' => 'Список записей',
        ];
    }

    /**
     * @inheritdoc
     */
    public function aclAlias()
    {
        return 'Медицинская карта';
    }
}
