<?php
namespace app\modules\medical\models\form;

use app\common\base\Model;
use app\common\helpers\CommonHelper;

/**
 * Class Policy
 * @package app\modules\medical\models\form
 */
class Policy extends Model
{
    public $id;
    public $expiration_date;
    public $issue_date;
    public $insurance_id;
    public $number;
    public $series;
    public $type;
    public $patient_id;


    /**
     * @inheritdoc
     */
    public function init()
    {
        if (!empty($this->expiration_date)) {
            $this->expiration_date = \Yii::$app->formatter->asDate($this->expiration_date, CommonHelper::FORMAT_DATE_UI);
        }
        if (!empty($this->issue_date)) {
            $this->issue_date = \Yii::$app->formatter->asDate($this->issue_date, CommonHelper::FORMAT_DATE_UI);
        }
    }

    /**
     * @return array
     */
    public static function types()
    {
        return [
            1 => 'ОМС',
            2 => 'ДМС',
        ];
    }

    /**
     * @return string|null
     */
    public function getTypeName()
    {
        $types = static::types();
        return isset($types[$this->type]) ? $types[$this->type] : null;
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
                [ [ 'issue_date', 'expiration_date' ], 'date', 'format' => CommonHelper::FORMAT_DATE_UI ],
                [ [ 'number', 'type', 'insurance_id' ], 'required' ],
                [ [
                    'expiration_date',
                    'issue_date',
                    'insurance_id',
                    'number',
                    'series',
                    'type',
                    'patient_id'
                ],
                'string' ]
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'expiration_date' => 'Дата окончания',
            'issue_date' => 'Дата оформления',
            'insurance_id' => 'Страховая компания',
            'number' => 'Номер',
            'series' => 'Серия',
            'type' => 'Тип',
            'patient_id' => 'Пациент',
        ];
    }
}
