<?php
namespace app\modules\organization\models\orm;

use app\common\logic\orm\AddressTrait;
use app\common\logic\orm\EmailTrait;
use app\common\db\ActiveRecord;
use app\common\helpers\CommonHelper;
use app\common\logic\orm\HumanTrait;
use app\common\logic\orm\PhoneTrait;
use app\common\logic\orm\Phone;
use app\modules\crm\models\orm\EmployeeToSpeciality;
use app\modules\medical\models\orm\Attendance;
use app\modules\medical\models\orm\Speciality;
use app\modules\organization\OrganizationModule;
use app\modules\security\models\orm\User;
use yii\validators\EmailValidator;
use yii\validators\RequiredValidator;

/**
 * Class Employee
 *
 * @property string $user_id
 * @property string $first_name
 * @property string $middle_name
 * @property string $last_name
 * @property int $status
 * @property int $sex
 * @property int $education
 * @property string $birthday
 * @property-read string $fullName
 * @property-read Phone[] $phones
 *
 * @package app\modules\organization\models\orm
 *
 * 
 */
class Employee extends ActiveRecord
{
    use HumanTrait;
    use PhoneTrait;
    use EmailTrait;
    use AddressTrait;


    public function getUser()
    {
        return $this->hasOne(User::class, ['id' => 'user_id']);
    }

    public function getSpeciality()
    {
        return $this->hasOne(Speciality::class, ['id' => 'speciality_id']);
    }

    public function getAttendances()
    {
        return $this->hasMany(Attendance::class, ['employee_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQueryInterface
     */
//    public function getPositionEmployees()
//    {
//        return $this->hasMany(PositionEmployee::className(), ['employee_id' => 'id']);
//    }

//    /**
//     * @return \yii\db\ActiveQueryInterface
//     */
//    public function getPositions()
//    {
//        return $this->hasMany(Position::className(), ['id' => 'position_id'])
//            ->via('positionEmployees');
//    }

    public function getEmployeeToSpeciality()
    {
        return $this->hasMany(EmployeeToSpeciality::class, ['employee_id' => 'id']);
    }

    public function getSpecialities()
    {
        return $this->hasMany(Speciality::class, ['id' => 'speciality_id'])
            ->via('employeeToSpeciality');
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [ ['first_name', 'last_name', 'sex', 'speciality_id', 'birthday'],
                'required',
                'on' => ['create', 'update']
            ],
            [ ['first_name', 'last_name', 'middle_name', 'speciality_id', 'user_id'],
                'string',
                'on' => ['create', 'update']
            ],
            [ ['status', 'sex', 'education'],
                'integer',
                'on' => ['create', 'update']
            ],
            [ ['birthday'],
                'filter',
                'filter' => function () {
                    return $this->birthday = \Yii::$app->formatter->asDate($this->birthday, CommonHelper::FORMAT_DATE_DB);
                },
                'skipOnEmpty' => true,
                'on' => ['create', 'update']
            ],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabelsOverride()
    {
        return [
            'user_id' => OrganizationModule::t('common', 'User'),
            'last_name' => OrganizationModule::t('common', 'Last name'),
            'first_name' => OrganizationModule::t('common', 'First name'),
            'middle_name' => OrganizationModule::t('common', 'Middle name'),
            'birthday' => OrganizationModule::t('common', 'Birthday'),
            'sex' => OrganizationModule::t('common', 'Sex'),
            'phones' => OrganizationModule::t('common', 'Phones'),
            'emails' => OrganizationModule::t('common', 'E-mail'),
            'speciality_id' => 'Специальность',
        ];
    }
}
