<?php
namespace app\modules\security\application;

use app\common\acl\resource\ApplicationResourceInterface;
use app\common\base\Model;
use app\common\data\ActiveDataProvider;
use app\common\helpers\CommonHelper;
use app\common\service\exception\AccessApplicationServiceException;
use app\modules\security\models\finders\UserFinder;
use app\modules\security\models\orm\User;
use app\common\service\ApplicationService;
use yii\web\IdentityInterface;

/**
 * Class UserService
 * @package app\modules\security\application
 *
 *
 */
class UserService extends ApplicationService implements UserServiceInterface, ApplicationResourceInterface
{
    /**
     * @inheritdoc
     */
    public function aclAlias()
    {
        return 'Пользователь';
    }

    /**
     * @inheritdoc
     */
    public function getPrivileges()
    {
        return [
            'getUserList' => 'Список пользователей',
        ];
    }

    /**
     * @inheritdoc
     */
    public function getUserList(Model $form)
    {
        /** @var $form UserFinder */
        if (!$this->isAllowed('getUserList')) {
            throw new AccessApplicationServiceException('Доступ к списку пользователей запрещён.');
        }
        $query = User::find();
        $query
            ->andFilterWhere([
                'cast(updated_at as date)' =>
                    empty($form->updatedAt) ? null : \Yii::$app->formatter->asDate($form->updatedAt, CommonHelper::FORMAT_DATE_DB),
            ]);
        return new ActiveDataProvider([
            'query' => $query,
            'pagination' => [
                'pageSize' => 10
            ],
        ]);
    }

    /**
     * @inheritdoc
     */
    public function init()
    {
        $this->modelClass = User::class;
        parent::init();
    }

    /**
     * @param IdentityInterface $identity
     * @param $duration
     * @return bool
     */
    public function login(IdentityInterface $identity, $duration)
    {
        return \Yii::$app->user->login($identity, $duration);
    }
}
