<?php
namespace app\modules\security\models\orm;

use app\common\db\ActiveQuery;
use app\common\db\ActiveRecord;

/**
 * Class AccessAcl
 *
 * @property int $type
 * @property int $permission
 * @property AclRole $role
 *
 * @package app\modules\security\models\orm
 *
 *
 */
class Acl extends ActiveRecord
{
    const TYPE_ACL_ALLOW = 1;
    const TYPE_ACL_DENY = 2;

    const TYPE_SERVICE = 1;
    const TYPE_WORKFLOW = 2;

    const RULE_AUTHOR = 0x01;
    const RULE_RESPONSIBILITY = 0x02;
    const RULE_POSITION = 0x04;
    const RULE_DEPARTMENT = 0x08;
//    const RULE_RESPONSIBILITY_HEAD = ;

    /**
     * @inheritdoc
     */
    public function init()
    {
        if ($this->isNewRecord) {
            $this->type_acl = $this::TYPE_ACL_ALLOW;
        }
        parent::init();
    }

    /**
     * @return array
     */
    public static function aclRules()
    {
        return [
            self::RULE_AUTHOR => 'Автор',
            self::RULE_RESPONSIBILITY => 'Ответственный',
            self::RULE_POSITION => 'Должность',
            self::RULE_DEPARTMENT => 'Подразделение',
        ];
    }

    /**
     * @inheritdoc
     */
    public function beforeSave($insert)
    {
        if (!parent::beforeSave($insert)) {
            return false;
        }
        $result = null;
//            if (!empty($model->permission)) {
//                foreach ($model->permission as $p) { // @todo afterSave() in model
//                    $result |= $p;
//                }
//                $model->permission = $result;
//                $result = null;
//            }
        if (!empty($this->rule)) {
            foreach ($this->rule as $r) {
                $result |= $r;
            }
            $this->rule = $result;
        }
        return true;
    }

    /**
     * @param $insert
     * @param $changedAttributes
     */
    public function afterSave($insert, $changedAttributes)
    {
        $rules = static::aclRules();
        $result = [];
        if (!empty($this->rule)) {
            foreach ($rules as $key => $r) {
                if ($this->rule & $key) {
                    $result[] = $key;
                }
            }
            $this->rule = $result;
        }
        parent::afterSave($insert, $changedAttributes);
    }

    /**
     * @inheritdoc
     */
    public function afterFind()
    {
//        $permissions = static::recordPermissions();
//        $result = [];
//        foreach ($permissions as $key => $p) {
//            if ($this->permission & $key) {
//                $result[] = $key;
//            }
//        }
//        $this->permission = $result;
        $rules = static::aclRules();
        $result = [];
        if (!empty($this->rule)) {
            foreach ($rules as $key => $r) {
                if ($this->rule & $key) {
                    $result[] = $key;
                }
            }
            $this->rule = $result;
        }
        parent::afterFind();
    }

    /**
     * @inheritdoc
     */
    public static function modelIdentity()
    {
        return ['module', 'type', 'type_acl', 'entity_type', 'acl_role_id', 'action'];
    }

    /**
     * @return array
     */
    public static function types()
    {
        return [
            static::TYPE_SERVICE => 'Служба',
            static::TYPE_WORKFLOW => 'Конечный автомат',
        ];
    }

    public function getTypeName()
    {
        $types = $this::types();
        return !isset($types[$this->type]) ?: $types[$this->type];
    }

    /**
     * @return array
     */
    public static function aclTypes()
    {
        return [
            static::TYPE_ACL_ALLOW => 'Разрешить',
            static::TYPE_ACL_DENY => 'Запретить',
        ];
    }

    public function getTypeAclName()
    {
        $types = $this::aclTypes();
        return isset($types[$this->type_acl]) ? $types[$this->type_acl] : '';
    }

//    public static function typeAclMap()
//    {
//
//    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [ ['module'],
                'unique',
                'filter' => function (ActiveQuery $query) {
                    return $query
                        ->notDeleted();
                },
                'targetAttribute' => ['module', 'type', 'type_acl', 'entity_type', 'acl_role_id', 'action']
            ],
            [ ['type', 'type_acl'],
                'integer'
            ],
            [ ['module', 'entity_type', 'acl_role_id', 'type_acl', 'action'], 'required' ],
            [ [
                'module',
                'entity_type',
                'entity_id',
                'acl_role_id',
                'criteria_formula'
            ],
                'string'
            ],
//            [ ['action'],
//                'each',
//                'when' => function ($model) {
//                    return is_array($model->permission);
//                },
//                'rule' => ['integer']
//            ],
            [
                ['rule'],
                'each',
                'when' => function ($model) { // for only validation
                    return is_array($model->rule);
                },
                'rule' => ['integer']
            ]
        ];
    }

//    /**
//     * @return array
//     */
//    public static function accessRules()
//    {
//        return [
//            self::RULE_AUTHOR => 'Автор',
//            self::RULE_RESPONSIBILITY => 'Ответственный',
//            self::RULE_POSITION => 'Должность',
//            self::RULE_DEPARTMENT => 'Подразделение',
////            self::RULE_HEAD_RESPONSIBILITY => 'Главный ответственный',
//        ];
//    }

//    /**
//     * @return array
//     */
//    public static function recordPermissions()
//    {
//        return [
//            self::PERMISSION_READ => 'Чтение',
//            self::PERMISSION_WRITE => 'Запись',
//            self::PERMISSION_UPDATE => 'Обновление',
//            self::PERMISSION_DELETE => 'Удаление',
//        ];
//    }

//    /**
//     * @return string
//     */
//    public function getRecordPermissionName()
//    {
//        $permissions  = $this::recordPermissions();
//        $result = '';
//        if (!empty($this->permission) && is_array($this->permission)) {
//            foreach ($this->permission as $key) {
//                $result .= $permissions[$key] . ' ';
//            }
//        }
//        return $result;
//    }

    /**
     * @return string
     */
    public function getRuleName()
    {
        $rules  = $this::aclRules();
        $result = '';
        if (!empty($this->rule) && is_array($this->rule)) {
            foreach ($this->rule as $key) {
                $result .= $rules[$key] . ' ';
            }
        }
        return $result;
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getAclRole()
    {
        return $this->hasOne(AclRole::class, ['id' => 'acl_role_id']);
    }

    /**
     * @inheritdoc
     */
    public function attributeLabelsOverride()
    {
        return [
            'module' => 'Модуль',
            'entity_type' => 'Ресурс',
            'action' => 'Привилегия',
            'type_acl' => 'Доступ',
            'type' => 'Тип',
            'acl_role_id' => 'Роль',
            'rule' => 'Бизнес-правило',
        ];
    }
}
