<?php
namespace app\modules\security\models\orm;

use app\common\db\ActiveQuery;
use app\common\db\ActiveRecord;
use app\common\db\Exception;
use app\modules\organization\models\orm\Employee;
use yii\db\ActiveQueryInterface;
use yii\web\IdentityInterface;

/**
 * Class User
 *
 * @property string $auth_key
 * @property string $login
 * @property string $password_hash
 *
 * @package app\modules\security\models\orm
 *
 *
 */
class User extends ActiveRecord implements IdentityInterface
{
    /**
     * @return array
     */
    public static function modelIdentity()
    {
        return ['login'];
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [
                'login',
                'unique',
                'filter' => function (ActiveQueryInterface $query) {
                    return $query->notDeleted();
                },
                'on' => [ActiveRecord::SCENARIO_CREATE, ActiveRecord::SCENARIO_UPDATE]
            ],
            [ ['login', 'acl_role_id'], 'string' ],
            [ ['login', 'password_hash', 'acl_role_id'], 'required', 'on' => ActiveRecord::SCENARIO_CREATE ],
            [ ['password_hash'], 'filter', 'filter' => function ($value) {
                return \Yii::$app->security->generatePasswordHash($value);
            }, 'on' => ActiveRecord::SCENARIO_CREATE ],
        ];
    }

    /**
     * @param bool $access
     * @return ActiveQuery
     */
    public function getEmployees($access = true)
    {
        return $this->hasMany(Employee::class, ['user_id' => 'id'])
            ->setAccess($access);
    }

    public function getAclRole()
    {
        return $this->hasOne(AclRole::class, ['id' => 'acl_role_id']);
    }

    /**
     * @inheritdoc
     */
    public static function findIdentity($id)
    {
        $record = static::find()
            ->where([
                'id' => $id,
            ])
            ->setAccess(false)
            ->notDeleted()
            ->one();
        return $record;
    }

    /**
     * @inheritdoc
     */
    public static function findIdentityByAccessToken($token, $type = null)
    {
        $record = static::find()
            ->where([
                'access_token' => $token,
            ])
            ->notDeleted()
            ->one();
        return $record;
    }

    /**
     * @inheritdoc
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * @inheritdoc
     */
    public function getAuthKey()
    {
        return $this->auth_key;
    }

    /**
     * @inheritdoc
     */
    public function validateAuthKey($authKey)
    {
        return $this->getAuthKey() === $authKey;
    }

    /**
     * @inheritdoc
     */
    public function attributeLabelsOverride()
    {
        return [
            'login' => 'Логин',
            'password_hash' => 'Пароль',
            'acl_role_id' => 'Роль',
            ''
        ];
    }
}
