<?php
namespace app\modules\security\port\ui\controllers;

use app\common\base\Module;
use app\common\db\ActiveRecord;
use app\common\web\CrudController;
use app\common\widgets\ActiveForm;
use app\modules\security\models\form\LoginForm;
use app\modules\security\application\UserService;
use app\modules\security\application\UserServiceInterface;
use yii\filters\AccessControl;

/**
 * Class UserController
 * @package app\modules\security\port\ui\controllers
 *
 * 
 */
class UserController extends CrudController
{
    /**
     * @var UserService
     */
    private $userService;


    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::class,
                'except' => ['login-form', 'login', 'validate-login', 'view', 'create', 'validate-create'],
                'rules' => [
                    [
                        'allow' => true,
                        'roles' => ['@'],
                    ],
                ],
            ],
        ];
    }

    /**
     * UserController constructor.
     * @param string $id
     * @param UserServiceInterface $userService
     * @param Module $module
     * @param array $config
     */
    public function __construct($id, Module $module, UserServiceInterface $userService, array $config = [])
    {
        $this->userService = $userService;
        parent::__construct($id, $module, $config);
    }

    public function actionCreate()
    {
        $modelClass = $this->modelClass;
        /** @var $modelClass ActiveRecord */
        $model = $modelClass::ensureWeak(null, $this->createScenario, \Yii::$app->request->getBodyParams());
        $form = new LoginForm([
            'login' => $model->login,
            'password' => $model->password_hash,
        ]);
        $model->save();
        if (\Yii::$app->user->getIsGuest()) {
            $form->validate();
            $this->userService->login($form->identity, 36000);
            return $this->goHome();
        } else {
            return $this->asJson($model);
        }
    }

    public function actionLoginForm()
    {
        return $this->render('login');
    }

    public function actionValidateLogin()
    {
        $model = new LoginForm();
        $model->load(\Yii::$app->getRequest()->getBodyParams());
        return $this->asJson(ActiveForm::validate($model));
    }

    public function actionLogin()
    {
        $model = new LoginForm();
        if (
            $model->load(\Yii::$app->request->post())
            && $model->validate()
            && $this->userService->login($model->identity, 36000)
        ) {
            return $this->goBack();
        }
        return $this->goHome();
    }

    public function actionLogout()
    {
        if(\Yii::$app->user->logout()) {
            return $this->redirect(['/security/ui/user/login-form']);
        }
        return $this->redirect(\Yii::$app->getUser()->loginUrl);
    }
}
