<?php
namespace app\modules\workplan\models\orm;

use app\common\db\ActiveRecord;
use app\common\helpers\CommonHelper;
use app\modules\organization\models\orm\Employee;

/**
 * Class Workplan
 *
 * @property string $id
 * @property int $status
 * @property string $employee_id
 * @property-read int[] $weekIds
 * @property-read WorkplanToWeek $workplanToWeeks
 * @property-read Employee $employee
 *
 * @package app\modules\organization\modules\workplan\models
 *
 * 
 */
class Workplan extends ActiveRecord
{
    const STATUS_ACTIVE = 1;
    const STATUS_INACTIVE = 2;


    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            ['status', 'integer'],
            [ ['employee_id', 'department_id', 'cabinet_id'],
                'string'],
            [ ['since_date', 'expire_date', 'since_time', 'expire_time', 'employee_id'],
                'required',
                'on' => ['create', 'update']
            ],
            [ ['since_date', 'expire_date'],
                'filter',
                'filter' => function ($value) {
                    return \Yii::$app->formatter->asDate($value, CommonHelper::FORMAT_DATE_DB);
                },
                'on' => ['create', 'update']
            ],
            [ ['since_time', 'expire_time'],
                'time',
                'format' => CommonHelper::FORMAT_TIME_DB,
                'on' => ['create', 'update']
            ],
        ];
    }

    /**
     * @todo по сути этот метод тут и не нужен. Вынести в форму
     * @return int[]
     * @deprecated todo перенести в форму
     */
    public function getWeekIds()
    {
        $w = $this->workplanToWeeks;
        $weekIds = [];
        foreach ($w as $week) {
            array_push($weekIds, $week->week);
        }
        return $weekIds;
    }

    public function getEmployee()
    {
        return $this->hasOne(Employee::class, ['id' => 'employee_id']);
    }

    public function getWorkplanToWeeks()
    {
        return $this->hasMany(WorkplanToWeek::class, ['workplan_id' => 'id']);
    }

    /**
     * @inheritdoc
     */
    public function attributeLabelsOverride()
    {
        return [
            'since_date' => 'Дата начала',
            'expire_date' => 'Дата конца',
            'since_time' => 'Время начала',
            'expire_time' => 'Время конца',
            'department_id' => 'Подразделение',
            'cabinet_id' => 'Кабинет',
            'weekIds' => 'Дни недели',
            'employee_id' => 'Сотрудник',
        ];
    }
}
