<?php
namespace app\port\rest\controllers;

use app\common\acl\resource\ApplicationResourceInterface;
use app\common\helpers\ClassHelper;
use app\common\rest\Controller;
use app\common\service\ServiceRegistry;
use app\common\workflow\WorkflowRegistry;
use app\modules\security\models\orm\Acl;
use app\modules\security\application\AclService;
use yii\base\Exception;
use yii\base\Module;

/**
 * Class AclResourceRegistryController
 * @package app\port\rest\controllers
 */
class AclResourceRegistryController extends Controller
{
    /**
     * @var ServiceRegistry
     */
    public $registry;


    /**
     * ServiceRegistryController constructor.
     * @param string $id
     * @param Module $module
     * @param ServiceRegistry $registry
     * @param array $config
     */
    public function __construct($id, Module $module, ServiceRegistry $registry, array $config = [])
    {
        $this->registry = $registry;
        parent::__construct($id, $module, $config);
    }

    public function actionRegistry()
    {
        $module = \Yii::$app->request->getQueryParam('module');
        $aclType = (int)\Yii::$app->request->getQueryParam('aclType');
        return AclService::resourceRegistry($module, $aclType);
    }

    public function actionPrivileges()
    {
        $module = \Yii::$app->request->getQueryParam('module');
        $aclType = (int)\Yii::$app->request->getQueryParam('aclType');
        $entityType = \Yii::$app->request->getQueryParam('entityType');
        $service = AclService::getResourceClass($module, $entityType, $aclType);
        if (!ClassHelper::implementsInterface($service, ApplicationResourceInterface::class)) {
            return [];
        }
        return $this->asJson(\Yii::createObject($service)->getPrivileges());
    }
}
